const http = require("https");

function summary(text) {
    return new Promise(async (resolve, reject) => {
        const options = {
            method: "POST",
            hostname: "api.apyhub.com",
            port: null,
            path: "/ai/summarize-text",
            headers: {
                "apy-token": process.env.SUMMARY_API_TOKEN,
                "Content-Type": "application/json",
            },
        };

        const req = http.request(options, function (res) {
            const chunks = [];

            res.on("data", function (chunk) {
                chunks.push(chunk);
            });

            res.on("end", function () {
                const body = Buffer.concat(chunks);
                if (res.statusCode !== 200) return reject("API HUB response code: " + res.statusCode + ".\nbody:\n" + body.toString());
                try {
                    resolve(JSON.parse(body.toString()).data.summary);
                } catch (error) {
                    reject(error);
                }
            });
        });
        req.on("error", reject);

        req.write(
            JSON.stringify({
                text: text,
                output_language: "cs",
                summary_length: "medium",
            })
        );
        req.end();
    });
}
module.exports = summary;

// summary(`Velikost běžných archeí se pohybuje ve stejném rozmezí jako velikost bakterií: 1 – 15 µm. Jejich tvar je také velmi podobný: kulovitý, tyčinkovitý, spirálovitý. I v této skupině existují velikostní i tvarové výjimky, například překvapivě pravidelný tvar jako má Haloquadratum, či dokonce tvar s tenkými výběžky, který najdeme u Prometheoarcheum. Vzhledem k tomu, že se archea dají nesmírně obtížně kultivovat a většinu jich známe pouze jako sekvence DNA (jinak je nikdo nespatřil), čeká nás pravděpodobně ještě řada překvapení.

// Cytoplazmatická membrána

// Každá buňka musí být od okolního prostředí oddělena cytoplazmatickou membránou a archea nejsou výjimkou. Jejich membrána je však odlišná od membrán bakterií i eukaryot. Eukaryotní a bakteriální cytoplazmatická membrána je složená z fosfolipidů a tyto fosfolipidy mají dvě mastné kyseliny připojené esterovou vazbou na glycerol.

// Odlišnosti mezi oběma typy fosfolipidů jsou popsány v textu.
// Membrána archeí obsahuje také fosfolipidy. Jejich hydrofobní část však netvoří mastná kyselina, ale izopren, který je k hydrofilní části připojen éterovou vazbou na glycerol. Éterová vazba je o něco stabilnější než esterová vazba, jež se nachází u bakterií a eukaryot. Archea používají také jiný optický izomer (enantiomer) glycerolu než ostatní buňky. Zatímco u bakterií a eukaryot nalézáme D-glycerol, zde se potkáváme výhradně s L-glycerolem. Vypadá to jako maličkost, která ani nestojí za zmínku. Musíme si ale uvědomit, že enzymy vyrábějící tyto po chemické stránce stejné molekuly, jsou naprosto odlišné. Tyto zdánlivé maličkosti tak vypovídají o hlubokých rozdílech mezi doménami.

// Poměrně často jsou také izopreny obou vrstev navzájem propojeny, a tak vznikne svým způsobem fosfolipidová jednovrstva. Nicméně i tato jednovrstva má na každou stranu hydrofilní hlavičku, takže vykazuje všechny vlastnosti cytoplazmatické membrány. Výhodou tohoto uspořádání je vyšší stabilita a využívají ho obzvlášť extrémofilní archea.

// Extracelulární vezikuly (EV)

// Thermococcus prieurii, který tvoří vlákna s extracelulárními vezikuly.
// Řada archeí dokáže vytvářet drobné váčky s různou funkcí mimo buňku. Tyto váčky „pučí“ z cytoplazmatické membrány, takže jsou obklopeny fosfolipidovými membránami a nesou materiál pocházející z cytoplazmy. Tyto vezikuly plní podle druhu organizmu mnoho funkcí. Jedná se například o detoxikaci, tvorbu biofilmu či přenos genetického materiálu.

// Nedávná studie (2021) zkoumala proces tvorby membránových vezikul u Sulfolobus. Ukázalo se, že je tento proces závislý na proteinech evolučně spřízněných s eukaryotickými proteiny řídícími tvorbu endozomálních váčků (váčků uvnitř eukaryotické buňky). Jedná se o jednu z podobností mezi archei a eukaryoty. Právě takovéto zdánlivě drobné podobnosti poukazují na příbuznost mezi doménami a jsou významné při sestavování fylogenetických stromů.

// S-vrstva a buněčná stěna

// S-vrstva i buněčná stěna je pevná struktura na povrchu archeí s mnoha funkcemi. Primárně se jedná o funkci ochrannou a dále přes tyto struktury buňka komunikuje s okolním prostředím, umožňují adhezi k povrchům atd.

// Nejčastější povrchovou strukturou archeí je tzv. S-vrstva. Jedná se o ochrannou vrstvu tvořenou membránovými bílkovinami schopnými samouspořádání. Tyto bílkoviny jsou na jedné straně ukotveny v membráně a na straně druhé vytvářejí jakýsi „klobouček“. Kloboučky do sebe navzájem zapadají, takže vznikne vnější povrch. Mezi kloboučky a membránou vzniká prostor vzdáleně podobný periplazmatickému prostoru bakterií.

// Umělecká představa různých typů S-vrstev. Jedná se o bílkoviny propojené s cytoplazmatickou membránou, popřípadě s pseudopeptydoglykanem.
// Proteiny S-vrstvy jsou v archeální doméně nesmírně pestré. V rámci jedné S-vrstvy však nalézáme jeden, maximálně dva typy bílkovin. Na druhou stranu však proteiny S-vrstvy příbuzných archeí mohou být úplně odlišné. Tloušťka této vrstvy se pohybuje mezi 5 až 25 nm s póry velkými 2 až 8 nm.

// Specifickou buněčnou stěnu mají archea z řádu Methanobacteriales, u nichž je základním stavebním prvkem buněčné stěny pseudopeptydoglykan (někdy se mu říká také pseudomurein). Strukturálně vypadá úplně jako peptidoglykan bakterií, ale po chemické stránce se liší. Například na něj neúčinkuje enzym lysozym, který bakteriální peptidoglykan rozkládá.

// Bičík (archaellum)

// Schéma výstavby a pohybu archeálního bičíku.
// Archea velmi často vlastní bičík. Bylo by však lépe, kdyby se jmenoval vrtule či lodní šroub. Jeho pohyb totiž není vlnivý jako pohyb biče. Tento bičík je tuhý, stočený do spirály jako vývrtka a rotuje. Také proto se prosazuje pojmenování archaellum (složenina ze slov archaea a flagellum).

// Ačkoli vykazuje stejný typ pohybu jako bičík bakteriální, vznikl z jiných struktur a podobnost je v tomto případě náhodná. Při genetických studiích se nenašel žádný gen související se strukturou bičíku, který by byl alespoň podobný s bakteriálními geny. Archeální bičík je podobný spíše bakteriálnímu pilu typu IV. Bakteriální bičík je dutý a roste na vzdáleném konci, archeální bičík dutý není a roste z místa, kde je ukotven do membrány přidáváním bičíkových proteinů (to je právě ta podobnost s bakteriálním pilem typu IV). Energii k rotaci získává archeální bičík díky ATP. I v tomto bodě se skrývá podobnost s pilem. Archeální bičík se na rozdíl od bakteriálního dokáže točit oběma směry. Buňka se podle smyslu rotace pohybuje buď vpřed, či vzad. Rychlost, kterou některá archea díky bičíku dosáhnou, je také úctyhodná. Za sekundu překonají vzdálenost až 500 x větší než je délka jejich těla. (Jen pro zajímavost. Člověk, jež by dokázal za sekundu překonat 500 násobek délky vlastního těla, by se pohyboval 2,5 x vyšší rychlostí než zvuk.)

// Kanyly, hamus

// Hamy na snímcích z elektronového mikroskopu. Pravý obrázek schéma hamu.
// Podobně jako bakterie, mají i archea různé povrchové struktury. Některé, jako archeální bičíky a pili, se na první pohled zdají být podobné svým bakteriálním protějškům, ale nesou významné rozdíly. Byla nalezena archea, která si vyvinula zajímavé povrchové struktury sloužící zpravidla k ukotvení buňky. První strukturou jsou kanyly. Byly objeveny u některých mořských archeálních kmenů. Zdá se, že tyto duté trubkovité struktury spojují buňky po dělení, což nakonec vede k husté síti složené z mnoha buněk a trubek. To by mohlo sloužit jako prostředek k ukotvení společenství buněk k povrchu. Kanyly nepropojují cytoplazmy buněk, vedou totiž pouze z „periplazmatického“ prostoru.

// Další strukturou jedinečnou pro archaea je hamus, dlouhý spirálovitý výběžek se třemi háčky na vzdáleném konci. Hlava s háčky má průměr kolem 60 nm a je schopná adheze na lecjaký povrch, popřípadě se díky háčkům mohou buňky držet jedna druhé. Obě tyto schopnosti buňky využívají při vytváření biofilmů. Z každé buňky vybíhá kolem 100 těchto přívěsků na všechny strany.`).then(console.log);
