const fs = require("fs");
const path = require("path");
const { writeFile, readdir } = require("node:fs/promises");
const { Config } = require("../db/db");

const OUTPUT_PATH = process.env.static_public;
const TEMPLATES_PATH = path.join(__dirname, "templates");

/**
 * @param {String} templateFile of the file to build
 * @param {Object} data to be passed to templates (example: Config.get())
 * @throws error
 */
async function buildFile(configData, templateFile) {
    try {
        // loading template
        let dataTemplate = fs.readFileSync(templateFile, "utf8");
        const data = eval("module.exports = d => `" + dataTemplate + "`"); //${d}
        let outFile = path.join(OUTPUT_PATH, path.basename(templateFile));
        let outFileRestore;
        try {
            outFileRestore = fs.readFileSync(outFile, "utf8");
        } catch (e) {}
        await writeFile(outFile, data(configData), { encoding: "utf-8" }).catch((e) => {
            writeFile(outFile, outFileRestore, { encoding: "utf-8" });
            throw e;
        });
        console.log("Builded:", path.basename(outFile));
    } catch (err) {
        console.error("BUILDING ERROR...\n", "FILE: " + path.basename(templateFile) + "\n", err.stack || err);
        throw err;
    }
}

module.exports = {
    /**
     * @throws err
     */
    async build() {
        console.group("Build started");
        let templates = await readdir(TEMPLATES_PATH);
        if (templates < 1) {
            throw Error("Templates for build were not found.");
        }
        let configData = await Config.get();
        let p = [];
        for (const t of templates) {
            p.push(buildFile(configData, path.join(TEMPLATES_PATH, t)));
        }
        await Promise.all(p);
        console.groupEnd();
    },
    async modify(callback = () => {}) {
        let data = await Config.get();
        callback(data);
        await Config.save(data);
        await this.build();
    },
};
