require("localenv");
const express = require("express");
const { Activity } = require("../db/db");
const router = express.Router();
const { verifyRequestRole } = require("./auth");

router.get("/all", async (req, res) => {
    res.send(
        await Activity.getAll().catch((e) => {
            console.error(e);
            return [];
        })
    );
});

router.get("/activity/:id", async (req, res, next) => {
    try {
        let activity = await Activity.getById(req.params.id).catch((e) => (e.name === "CastError" ? res.status(404).send({ err: e.message }) : next(e)));
        if (!activity) return res.status(404).send({});
        res.send(activity);
    } catch (e) {
        next(e);
    }
});

router.get("/activitySlug/:slug", async (req, res, next) => {
    try {
        let activity = await Activity.get(req.params.slug);
        if (!activity) return res.status(404).send({});
        res.send(activity);
    } catch (e) {
        next(e);
    }
});

router.post("/activity", async (req, res, next) => {
    if (!verifyRequestRole(req, res, ["dev", "admin"])) return;
    try {
        res.send(await Activity.save(req.body));
    } catch (e) {
        next(e);
    }
});

router.delete("/activity/:id", async (req, res, next) => {
    if (!verifyRequestRole(req, res, ["dev", "admin"])) return;
    try {
        res.send(await Activity.delete(req.params.id));
    } catch (e) {
        next(e);
    }
});

module.exports = { router };
