import { createRouter, createWebHistory } from "vue-router";
import HomeView from "./views/HomeView.vue";
import { i18n } from "./translation.js";
const t = i18n.global.t;

const router = createRouter({
    history: createWebHistory(import.meta.env.BASE_URL),
    routes: [
        {
            path: "/",
            name: "home",
            component: HomeView,
            props: false,
        },
        {
            path: "/home",
            redirect: { name: "home" },
        },
        {
            path: "/activities/:activity?",
            name: "activities",
            component: () => import("@/views/ActivitiesView.vue"),
            props: true,
        },
        {
            path: "/globalconfig",
            name: "gconf",
            component: () => import("@/views/GlobalConfigView.vue"),
            props: false,
        },
        {
            path: "/a/:article?",
            name: "a",
            component: () => import("@/views/ArticleView.vue"),
            props: true,
        },
        {
            path: "/tb/:menu?/:article?",
            name: "tb",
            component: () => import("@/views/TextbookView.vue"),
            props: true,
        },
        {
            path: "/search/:query?",
            name: "search",
            component: () => import("@/views/SearchResultsView.vue"),
            props: true,
        },
        {
            path: "/err",
            name: "error",
            component: () => import("@/views/ErrorView.vue"),
            props: false,
            beforeEnter: () => {
                if (!window.err || (!window.err.code && !window.err.err)) return { name: "home" };
                else return true;
            },
        },
        {
            path: "/:pathMatch(.*)*",
            redirect: () => {
                window.err = { code: 404 };
                return { name: "error" };
            },
        },
    ],
    scrollBehavior(to, from, savedPosition) {
        return { left: 0, top: 0 };
    },
});

window.onbeforeunload = (e) => {
    window.speechSynthesis.cancel();
    if (window.isDirty) e.preventDefault();
};

router.beforeEach((to, from) => {
    if (window.isDirty) {
        const confirm = window.confirm(t("components.dialogs.toasts.unsaved.title"));
        if (confirm) window.isDirty = false;
        else return false;
    }

    switch (to.name) {
        case "a": {
            const article = to.params.article;
            if (!article || article === "home") return { name: "home" };
            if (article === "activities") return { name: "activities" };
            break;
        }
        case "tb": {
            const menu = to.params.menu;
            if (!menu) return { name: "home" };
            break;
        }
    }
});

router.onError((err) => {
    console.error("ROUTER ERR...\n", err);
    return router.push({ name: "error" });
});

export default router;
