import { createI18n } from "vue-i18n";
import cs from "@/assets/locales/cs.json";
import en from "@/assets/locales/en.json";

const loadedLocales = ["cs", "en"];
const availableLocales = [...loadedLocales, "sk", "es", "de"];

const i18n = createI18n({
    legacy: false,
    locale: "cs",
    fallbackLocale: "en",
    messages: { cs, en },
});

async function lazyLoad(lang) {
    if (loadedLocales.includes(lang)) return;
    return import(`@/assets/locales/${lang}.json`).then((messages) => {
        loadedLocales.push(lang);
        i18n.global.setLocaleMessage(lang, messages.default);
    });
}

async function setLocale(lang) {
    if (!lang || !availableLocales.includes(lang)) lang = loadedLocales[0];
    await lazyLoad(lang);
    i18n.global.locale.value = lang;
    document.querySelector("html").setAttribute("lang", lang);
}

function getLocaleIndex(lang) {
    return availableLocales.findIndex((item) => item === lang);
}

export { i18n, availableLocales, setLocale, getLocaleIndex };
