import { fileURLToPath, URL } from "node:url";
import { defineConfig } from "vite";
import vue from "@vitejs/plugin-vue";

export default defineConfig({
    plugins: [vue()],
    build: {
        outDir: "../backend/vue_build",
        assetsDir: "./assets",
        rollupOptions: {
            output: {
                entryFileNames: "assets/[name].js",
                chunkFileNames: "assets/[name].js",
                assetFileNames: "assets/[name].[ext]",
            },
            external: ["blind-friendly-library"],
        },
    },
    resolve: {
        alias: {
            "@": fileURLToPath(new URL("./src", import.meta.url)),
        },
    },
    server: {
        port: 8080,
        proxy: {
            "/api": { target: "http://localhost:3000" },
            "/defaults": { target: "http://localhost:3000" },
            "/uploads": { target: "http://localhost:3000" },
            "/themes": { target: "http://localhost:3000" },
        },
    },
    css: {
        preprocessorOptions: {
            scss: {
                additionalData: `
                    @import "@/assets/css/_variables.scss";
                    @import "@/assets/css/_mixins.scss";
                    @import "@/assets/css/_placeholders.scss"; 
                    $node-env: ${process.env.NODE_ENV};
                `,
            },
        },
    },
});
